//
//  Copyright Rob Seward 2010
//
//  This file is part of Aestheticode.
//
//	Aestheticode is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	Aestheticode is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with Aestheticode.  If not, see <http://www.gnu.org/licenses/>.

/*
*
*  This app reads input from a file and displays the text onscreen as Aestheticode.
*  The input file ("input.txt" by default) MUST CONSIST ONLY OF LOWERCASE LETTERS.
*  Otherwise you will get an error.
*
*/


int num_panels = 3;
int[] panel_colors = new int[num_panels];
color[] colors = new color[3];
int spacing = 150;
int panel_size = 400;
int top_margin = 50;
String filename = "input.txt";
int left_margin;
Letter[] letters = new Letter[27];

color r = color(200,0,0);
color g = color(0,200,0);
color b = color(0,0,200);

char[] output;


void setup(){
  loadOutput();
  size(screen.width, screen.height);
  colors[0] = r;
  colors[1] = g;
  colors[2] = b;
  makeLetters();
  
  panel_size = width / 3 - 200;
  left_margin = (width - ((panel_size*3) + (spacing*2))) / 2;
  
  frameRate(1);
  noCursor();
}


int output_index;
void draw(){
  background(255);
  
  char character = output[output_index];
  Letter l = character == 32 ? letters[26] : letters[character - 97];

  for(int i=0; i < num_panels; i++){
    fill(l.colors[i]);
    
    rect(left_margin, (screen.height - (panel_size)) / 2, panel_size, panel_size); 
    translate(spacing + panel_size, 0);  
  }
  
  output_index++;
  if(output_index >= output.length) output_index = 0;
}


void makeLetters(){
  letters[0] = new Letter(r,r,r);
  letters[1] = new Letter(r,r, g);
  letters[2] = new Letter(r,r, b);
  letters[3] = new Letter(r, g,r);
  letters[4] = new Letter(r, g, g);
  letters[5] = new Letter(r, g, b);
  letters[6] = new Letter(r, b,r);
  letters[7] = new Letter(r, b, g);
  letters[8] = new Letter(r, b, b);
  letters[9] = new Letter( g,r,r);
  letters[10] = new Letter( g,r, g);
  letters[11] = new Letter( g,r, b);
  letters[12] = new Letter( g, g,r);
  letters[13] = new Letter( g, g, g);
  letters[14] = new Letter( g, g, b);
  letters[15] = new Letter( g, b,r);
  letters[16] = new Letter( g, b, g);
  letters[17] = new Letter( g, b, b);
  letters[18] = new Letter( b,r,r);
  letters[19] = new Letter( b,r, g);
  letters[20] = new Letter( b,r, b);
  letters[21] = new Letter( b, g,r);
  letters[22] = new Letter( b, g, g);
  letters[23] = new Letter( b, g, b);
  letters[24] = new Letter( b, b,r);
  letters[25] = new Letter( b, b, g);
  letters[26] = new Letter( b, b, b); 
}


//Load message from file
void loadOutput(){
  String[] lines = loadStrings(filename);
  String all_lines = "";
  for(int i=0; i < lines.length; i++){
     all_lines += lines[i]; 
  }
  output = all_lines.toCharArray();
}


class Letter{
  color[] colors = new color[num_panels];

  public Letter(color c1, color c2, color c3){
    colors[0] = c1;
    colors[1] = c2;
    colors[2] = c3;  
  }
}


